@@ -1,5 +1,4 @@
 use strict;
-
 use warnings;
 package App::Pastebin::Create;
 #ABSTRACT: Create and upload paste to pastebin (DOCUMENTATION IN DEVELOPMENT)
@@ -58,8 +57,7 @@ Your paste title description.
 
 =head1 SEE ALSO
 
-L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create"
-L< https://metacpan.org/pod/App::Nopaste"
+L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create", L< https://metacpan.org/pod/App::Nopaste"
 
 
 =head1 AUTHOR
